@@ -1,6 +1,7 @@
 from speasy import __version__
 import platform
 import requests
+from requests.utils import quote as _quote
 from time import sleep
 import logging
 
@@ -8,6 +9,8 @@ log = logging.getLogger(__name__)
 
 USER_AGENT = f'Speasy/{__version__} {platform.uname()} (SciQLop project)'
 
+def quote(*args, **kwargs):
+    return _quote(*args, **kwargs)
 
 def get(url, headers: dict = None, params: dict = None):
     headers = {} if headers is None else headers
